Method: Elasticsearch::API::Cat::Actions#thread_pool

Defined in:
lib/elasticsearch/api/actions/cat/thread_pool.rb

#thread_pool(arguments = {}) ⇒ Object

Returns cluster-wide thread pool statistics per node. By default the active, queue and rejected statistics are returned for all thread pools.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :thread_pool_patterns (List)

    A comma-separated list of regular-expressions to filter the thread pools in the output

  • :format (String)

    a short version of the Accept header, e.g. json, yaml

  • :time (String)

    The unit in which to display time values (options: d, h, m, s, ms, micros, nanos)

  • :local (Boolean)

    Return local information, do not retrieve the state from master node (default: false)

  • :master_timeout (Time)

    Explicit operation timeout for connection to master node

  • :h (List)

    Comma-separated list of column names to display

  • :help (Boolean)

    Return help information

  • :s (List)

    Comma-separated list of column names or column aliases to sort by

  • :v (Boolean)

    Verbose mode. Display column headers

  • :headers (Hash)

    Custom HTTP headers

See Also:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/elasticsearch/api/actions/cat/thread_pool.rb', line 41

def thread_pool(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || "cat.thread_pool" }

  defined_params = [:thread_pool_patterns].inject({}) do |set_variables, variable|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
    set_variables
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _thread_pool_patterns = arguments.delete(:thread_pool_patterns)

  method = Elasticsearch::API::HTTP_GET
  path   = if _thread_pool_patterns
             "_cat/thread_pool/#{Utils.__listify(_thread_pool_patterns)}"
           else
             "_cat/thread_pool"
           end
  params = Utils.process_params(arguments)
  params[:h] = Utils.__listify(params[:h]) if params[:h]

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end