Method: Elasticsearch::API::Cat::Actions#transforms

Defined in:
lib/elasticsearch/api/actions/cat/transforms.rb

#transforms(arguments = {}) ⇒ Object

Gets configuration and usage information about transforms.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :transform_id (String)

    The id of the transform for which to get stats. ‘_all’ or ‘*’ implies all transforms

  • :from (Integer)

    skips a number of transform configs, defaults to 0

  • :size (Integer)

    specifies a max number of transforms to get, defaults to 100

  • :allow_no_match (Boolean)

    Whether to ignore if a wildcard expression matches no transforms. (This includes _all string or when no transforms have been specified)

  • :format (String)

    a short version of the Accept header, e.g. json, yaml

  • :h (List)

    Comma-separated list of column names to display

  • :help (Boolean)

    Return help information

  • :s (List)

    Comma-separated list of column names or column aliases to sort by

  • :time (String)

    The unit in which to display time values (options: d, h, m, s, ms, micros, nanos)

  • :v (Boolean)

    Verbose mode. Display column headers

  • :headers (Hash)

    Custom HTTP headers

See Also:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/elasticsearch/api/actions/cat/transforms.rb', line 41

def transforms(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || "cat.transforms" }

  defined_params = [:transform_id].inject({}) do |set_variables, variable|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
    set_variables
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _transform_id = arguments.delete(:transform_id)

  method = Elasticsearch::API::HTTP_GET
  path   = if _transform_id
             "_cat/transforms/#{Utils.__listify(_transform_id)}"
           else
             "_cat/transforms"
           end
  params = Utils.process_params(arguments)

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end