Method: Elasticsearch::API::CrossClusterReplication::Actions#forget_follower

Defined in:
lib/elasticsearch/api/actions/cross_cluster_replication/forget_follower.rb

#forget_follower(arguments = {}) ⇒ Object

Removes the follower retention leases from the leader.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :index (String)

    the name of the leader index for which specified follower retention leases should be removed

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    the name and UUID of the follower index, the name of the cluster containing the follower index, and the alias from the perspective of that cluster for the remote cluster containing the leader index (Required)

Raises:

  • (ArgumentError)

See Also:



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/elasticsearch/api/actions/cross_cluster_replication/forget_follower.rb', line 33

def forget_follower(arguments = {})
  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'index' missing" unless arguments[:index]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body   = arguments.delete(:body)

  _index = arguments.delete(:index)

  method = Elasticsearch::API::HTTP_POST
  path   = "#{Utils.__listify(_index)}/_ccr/forget_follower"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers)
  )
end