Method: Elasticsearch::API::Inference::Actions#put
- Defined in:
- lib/elasticsearch/api/actions/inference/put.rb
#put(arguments = {}) ⇒ Object
Configure an inference endpoint for use in the Inference API This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/elasticsearch/api/actions/inference/put.rb', line 38 def put(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'inference.put' } defined_params = %i[inference_id task_type].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'inference_id' missing" unless arguments[:inference_id] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = arguments.delete(:body) _inference_id = arguments.delete(:inference_id) _task_type = arguments.delete(:task_type) method = Elasticsearch::API::HTTP_PUT path = if _task_type && _inference_id "_inference/#{Utils.__listify(_task_type)}/#{Utils.__listify(_inference_id)}" else "_inference/#{Utils.__listify(_inference_id)}" end params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |