Method: Elasticsearch::API::MachineLearning::Actions#delete_forecast

Defined in:
lib/elasticsearch/api/actions/machine_learning/delete_forecast.rb

#delete_forecast(arguments = {}) ⇒ Object

Deletes forecasts from a machine learning job.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :job_id (String)

    The ID of the job from which to delete forecasts

  • :forecast_id (String)

    The ID of the forecast to delete, can be comma delimited list. Leaving blank implies _all

  • :allow_no_forecasts (Boolean)

    Whether to ignore if _all matches no forecasts

  • :timeout (Time)

    Controls the time to wait until the forecast(s) are deleted. Default to 30 seconds

  • :headers (Hash)

    Custom HTTP headers

Raises:

  • (ArgumentError)

See Also:



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/elasticsearch/api/actions/machine_learning/delete_forecast.rb', line 35

def delete_forecast(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || "ml.delete_forecast" }

  defined_params = [:job_id, :forecast_id].inject({}) do |set_variables, variable|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
    set_variables
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'job_id' missing" unless arguments[:job_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _job_id = arguments.delete(:job_id)

  _forecast_id = arguments.delete(:forecast_id)

  method = Elasticsearch::API::HTTP_DELETE
  path   = if _job_id && _forecast_id
             "_ml/anomaly_detectors/#{Utils.__listify(_job_id)}/_forecast/#{Utils.__listify(_forecast_id)}"
           else
             "_ml/anomaly_detectors/#{Utils.__listify(_job_id)}/_forecast"
           end
  params = Utils.process_params(arguments)

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end