Method: Elasticsearch::API::MachineLearning::Actions#get_buckets

Defined in:
lib/elasticsearch/api/actions/machine_learning/get_buckets.rb

#get_buckets(arguments = {}) ⇒ Object

Retrieves anomaly detection job results for one or more buckets.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :job_id (String)

    ID of the job to get bucket results from

  • :timestamp (String)

    The timestamp of the desired single bucket result

  • :expand (Boolean)

    Include anomaly records

  • :exclude_interim (Boolean)

    Exclude interim results

  • :from (Integer)

    skips a number of buckets

  • :size (Integer)

    specifies a max number of buckets to get

  • :start (String)

    Start time filter for buckets

  • :end (String)

    End time filter for buckets

  • :anomaly_score (Double)

    Filter for the most anomalous buckets

  • :sort (String)

    Sort buckets by a particular field

  • :desc (Boolean)

    Set the sort direction

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    Bucket selection details if not provided in URI

Raises:

  • (ArgumentError)

See Also:



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/elasticsearch/api/actions/machine_learning/get_buckets.rb', line 43

def get_buckets(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || "ml.get_buckets" }

  defined_params = [:job_id, :timestamp].inject({}) do |set_variables, variable|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
    set_variables
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'job_id' missing" unless arguments[:job_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _job_id = arguments.delete(:job_id)

  _timestamp = arguments.delete(:timestamp)

  method = if body
             Elasticsearch::API::HTTP_POST
           else
             Elasticsearch::API::HTTP_GET
           end

  path   = if _job_id && _timestamp
             "_ml/anomaly_detectors/#{Utils.__listify(_job_id)}/results/buckets/#{Utils.__listify(_timestamp)}"
           else
             "_ml/anomaly_detectors/#{Utils.__listify(_job_id)}/results/buckets"
           end
  params = Utils.process_params(arguments)

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end