Method: Elasticsearch::API::MachineLearning::Actions#get_datafeeds

Defined in:
lib/elasticsearch/api/actions/machine_learning/get_datafeeds.rb

#get_datafeeds(arguments = {}) ⇒ Object

Retrieves configuration information for datafeeds.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :datafeed_id (String)

    The ID of the datafeeds to fetch

  • :allow_no_match (Boolean)

    Whether to ignore if a wildcard expression matches no datafeeds. (This includes _all string or when no datafeeds have been specified)

  • :exclude_generated (Boolean)

    Omits fields that are illegal to set on datafeed PUT

  • :headers (Hash)

    Custom HTTP headers

See Also:



34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/elasticsearch/api/actions/machine_learning/get_datafeeds.rb', line 34

def get_datafeeds(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || "ml.get_datafeeds" }

  defined_params = [:datafeed_id].inject({}) do |set_variables, variable|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
    set_variables
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _datafeed_id = arguments.delete(:datafeed_id)

  method = Elasticsearch::API::HTTP_GET
  path   = if _datafeed_id
             "_ml/datafeeds/#{Utils.__listify(_datafeed_id)}"
           else
             "_ml/datafeeds"
           end
  params = Utils.process_params(arguments)

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end