Method: Elasticsearch::API::MachineLearning::Actions#preview_datafeed

Defined in:
lib/elasticsearch/api/actions/machine_learning/preview_datafeed.rb

#preview_datafeed(arguments = {}) ⇒ Object

Previews a datafeed.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :datafeed_id (String)

    The ID of the datafeed to preview

  • :start (String)

    The start time from where the datafeed preview should begin

  • :end (String)

    The end time when the datafeed preview should stop

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    The datafeed config and job config with which to execute the preview

See Also:



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/elasticsearch/api/actions/machine_learning/preview_datafeed.rb', line 35

def preview_datafeed(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'ml.preview_datafeed' }

  defined_params = [:datafeed_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _datafeed_id = arguments.delete(:datafeed_id)

  method = if body
             Elasticsearch::API::HTTP_POST
           else
             Elasticsearch::API::HTTP_GET
           end

  path = if _datafeed_id
           "_ml/datafeeds/#{Utils.__listify(_datafeed_id)}/_preview"
         else
           '_ml/datafeeds/_preview'
         end
  params = Utils.process_params(arguments)

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end