Method: Elasticsearch::API::Transform::Actions#get_transform

Defined in:
lib/elasticsearch/api/actions/transform/get_transform.rb

#get_transform(arguments = {}) ⇒ Object

Retrieves configuration information for transforms.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :transform_id (String)

    The id or comma delimited list of id expressions of the transforms to get, ‘_all’ or ‘*’ implies get all transforms

  • :from (Integer)

    skips a number of transform configs, defaults to 0

  • :size (Integer)

    specifies a max number of transforms to get, defaults to 100

  • :allow_no_match (Boolean)

    Whether to ignore if a wildcard expression matches no transforms. (This includes _all string or when no transforms have been specified)

  • :exclude_generated (Boolean)

    Omits fields that are illegal to set on transform PUT

  • :headers (Hash)

    Custom HTTP headers

See Also:



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/elasticsearch/api/actions/transform/get_transform.rb', line 36

def get_transform(arguments = {})
  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _transform_id = arguments.delete(:transform_id)

  method = Elasticsearch::API::HTTP_GET
  path   = if _transform_id
             "_transform/#{Utils.__listify(_transform_id)}"
           else
             "_transform"
           end
  params = Utils.process_params(arguments)

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers)
  )
end