Module: Elasticsearch::API::Connector::Actions

Included in:
ConnectorClient
Defined in:
lib/elasticsearch/api/namespace/connector.rb,
lib/elasticsearch/api/actions/connector/get.rb,
lib/elasticsearch/api/actions/connector/put.rb,
lib/elasticsearch/api/actions/connector/list.rb,
lib/elasticsearch/api/actions/connector/post.rb,
lib/elasticsearch/api/actions/connector/delete.rb,
lib/elasticsearch/api/actions/connector/check_in.rb,
lib/elasticsearch/api/actions/connector/secret_get.rb,
lib/elasticsearch/api/actions/connector/secret_put.rb,
lib/elasticsearch/api/actions/connector/secret_post.rb,
lib/elasticsearch/api/actions/connector/update_name.rb,
lib/elasticsearch/api/actions/connector/sync_job_get.rb,
lib/elasticsearch/api/actions/connector/update_error.rb,
lib/elasticsearch/api/actions/connector/secret_delete.rb,
lib/elasticsearch/api/actions/connector/sync_job_list.rb,
lib/elasticsearch/api/actions/connector/sync_job_post.rb,
lib/elasticsearch/api/actions/connector/update_native.rb,
lib/elasticsearch/api/actions/connector/update_status.rb,
lib/elasticsearch/api/actions/connector/sync_job_claim.rb,
lib/elasticsearch/api/actions/connector/sync_job_error.rb,
lib/elasticsearch/api/actions/connector/sync_job_cancel.rb,
lib/elasticsearch/api/actions/connector/sync_job_delete.rb,
lib/elasticsearch/api/actions/connector/update_features.rb,
lib/elasticsearch/api/actions/connector/update_pipeline.rb,
lib/elasticsearch/api/actions/connector/update_filtering.rb,
lib/elasticsearch/api/actions/connector/sync_job_check_in.rb,
lib/elasticsearch/api/actions/connector/update_api_key_id.rb,
lib/elasticsearch/api/actions/connector/update_index_name.rb,
lib/elasticsearch/api/actions/connector/update_scheduling.rb,
lib/elasticsearch/api/actions/connector/update_service_type.rb,
lib/elasticsearch/api/actions/connector/update_configuration.rb,
lib/elasticsearch/api/actions/connector/sync_job_update_stats.rb,
lib/elasticsearch/api/actions/connector/update_active_filtering.rb,
lib/elasticsearch/api/actions/connector/update_filtering_validation.rb

Instance Method Summary collapse

Instance Method Details

#check_in(arguments = {}) ⇒ Object

Check in a connector This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

Raises:

  • (ArgumentError)

See Also:



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/elasticsearch/api/actions/connector/check_in.rb', line 36

def check_in(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.check_in' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_check_in"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#delete(arguments = {}) ⇒ Object

Delete a connector This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be deleted.

  • :delete_sync_jobs (Boolean)

    Determines whether associated sync jobs are also deleted.

  • :headers (Hash)

    Custom HTTP headers

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/elasticsearch/api/actions/connector/delete.rb', line 37

def delete(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.delete' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_DELETE
  path   = "_connector/#{Utils.__listify(_connector_id)}"
  params = Utils.process_params(arguments)

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#get(arguments = {}) ⇒ Object

Get a connector This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be returned.

  • :headers (Hash)

    Custom HTTP headers

Raises:

  • (ArgumentError)

See Also:



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/elasticsearch/api/actions/connector/get.rb', line 36

def get(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.get' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_GET
  path   = "_connector/#{Utils.__listify(_connector_id)}"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#list(arguments = {}) ⇒ Object

Get all connectors This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :from (Integer)

    Starting offset (default: 0)

  • :size (Integer)

    Specifies a max number of results to get (default: 100)

  • :index_name (List)

    A comma-separated list of connector index names to fetch connector documents for

  • :connector_name (List)

    A comma-separated list of connector names to fetch connector documents for

  • :service_type (List)

    A comma-separated list of connector service types to fetch connector documents for

  • :query (String)

    A search string for querying connectors, filtering results by matching against connector names, descriptions, and index names

  • :headers (Hash)

    Custom HTTP headers

See Also:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/elasticsearch/api/actions/connector/list.rb', line 41

def list(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.list' }

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body   = nil

  method = Elasticsearch::API::HTTP_GET
  path   = '_connector'
  params = Utils.process_params(arguments)

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#post(arguments = {}) ⇒ Object

Create a connector This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    The connector configuration.

See Also:



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/elasticsearch/api/actions/connector/post.rb', line 36

def post(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.post' }

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body   = arguments.delete(:body)

  method = Elasticsearch::API::HTTP_POST
  path   = '_connector'
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#put(arguments = {}) ⇒ Object

Create or update a connector This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be created or updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    The connector configuration.

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/elasticsearch/api/actions/connector/put.rb', line 37

def put(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.put' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = if _connector_id
             "_connector/#{Utils.__listify(_connector_id)}"
           else
             '_connector'
           end
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#secret_delete(arguments = {}) ⇒ Object

Deletes a connector secret This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :id (String)

    The ID of the secret

  • :headers (Hash)

    Custom HTTP headers

Raises:

  • (ArgumentError)

See Also:

  • [TODO]


36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/elasticsearch/api/actions/connector/secret_delete.rb', line 36

def secret_delete(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.secret_delete' }

  defined_params = [:id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'id' missing" unless arguments[:id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _id = arguments.delete(:id)

  method = Elasticsearch::API::HTTP_DELETE
  path   = "_connector/_secret/#{Utils.__listify(_id)}"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#secret_get(arguments = {}) ⇒ Object

Retrieves a secret stored by Connectors This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :id (String)

    The ID of the secret

  • :headers (Hash)

    Custom HTTP headers

Raises:

  • (ArgumentError)

See Also:

  • [TODO]


36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/elasticsearch/api/actions/connector/secret_get.rb', line 36

def secret_get(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.secret_get' }

  defined_params = [:id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'id' missing" unless arguments[:id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _id = arguments.delete(:id)

  method = Elasticsearch::API::HTTP_GET
  path   = "_connector/_secret/#{Utils.__listify(_id)}"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#secret_post(arguments = {}) ⇒ Object

Creates a secret for a Connector This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    The secret value to store (Required)

Raises:

  • (ArgumentError)

See Also:

  • [TODO]


36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/elasticsearch/api/actions/connector/secret_post.rb', line 36

def secret_post(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.secret_post' }

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body   = arguments.delete(:body)

  method = Elasticsearch::API::HTTP_POST
  path   = '_connector/_secret'
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#secret_put(arguments = {}) ⇒ Object

Creates or updates a secret for a Connector This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :id (String)

    The unique identifier of the connector secret to be created or updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    The secret value to store (Required)

Raises:

  • (ArgumentError)

See Also:

  • [TODO]


37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/secret_put.rb', line 37

def secret_put(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.secret_put' }

  defined_params = [:id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'id' missing" unless arguments[:id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _id = arguments.delete(:id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/_secret/#{Utils.__listify(_id)}"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#sync_job_cancel(arguments = {}) ⇒ Object

Cancel a connector sync job This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_sync_job_id (String)

    The unique identifier of the connector sync job to be canceled

  • :headers (Hash)

    Custom HTTP headers

See Also:



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/elasticsearch/api/actions/connector/sync_job_cancel.rb', line 36

def sync_job_cancel(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.sync_job_cancel' }

  defined_params = [:connector_sync_job_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  unless arguments[:connector_sync_job_id]
    raise ArgumentError,
          "Required argument 'connector_sync_job_id' missing"
  end

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _connector_sync_job_id = arguments.delete(:connector_sync_job_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/_sync_job/#{Utils.__listify(_connector_sync_job_id)}/_cancel"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#sync_job_check_in(arguments = {}) ⇒ Object

Check in a connector sync job This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_sync_job_id (String)

    The unique identifier of the connector sync job to be checked in

  • :headers (Hash)

    Custom HTTP headers

See Also:



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/elasticsearch/api/actions/connector/sync_job_check_in.rb', line 36

def sync_job_check_in(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.sync_job_check_in' }

  defined_params = [:connector_sync_job_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  unless arguments[:connector_sync_job_id]
    raise ArgumentError,
          "Required argument 'connector_sync_job_id' missing"
  end

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _connector_sync_job_id = arguments.delete(:connector_sync_job_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/_sync_job/#{Utils.__listify(_connector_sync_job_id)}/_check_in"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#sync_job_claim(arguments = {}) ⇒ Object

Claim a connector sync job This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_sync_job_id (String)

    The unique identifier of the connector sync job to be claimed.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    Data to claim a sync job. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/elasticsearch/api/actions/connector/sync_job_claim.rb', line 37

def sync_job_claim(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.sync_job_claim' }

  defined_params = [:connector_sync_job_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]

  unless arguments[:connector_sync_job_id]
    raise ArgumentError,
          "Required argument 'connector_sync_job_id' missing"
  end

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_sync_job_id = arguments.delete(:connector_sync_job_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/_sync_job/#{Utils.__listify(_connector_sync_job_id)}/_claim"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#sync_job_delete(arguments = {}) ⇒ Object

Delete a connector sync job This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_sync_job_id (String)

    The unique identifier of the connector sync job to be deleted.

  • :headers (Hash)

    Custom HTTP headers

See Also:



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/elasticsearch/api/actions/connector/sync_job_delete.rb', line 36

def sync_job_delete(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.sync_job_delete' }

  defined_params = [:connector_sync_job_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  unless arguments[:connector_sync_job_id]
    raise ArgumentError,
          "Required argument 'connector_sync_job_id' missing"
  end

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _connector_sync_job_id = arguments.delete(:connector_sync_job_id)

  method = Elasticsearch::API::HTTP_DELETE
  path   = "_connector/_sync_job/#{Utils.__listify(_connector_sync_job_id)}"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#sync_job_error(arguments = {}) ⇒ Object

Set a connector sync job error This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_sync_job_id (String)

    The unique identifier of the connector sync job to set an error for.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    The error to set in the connector sync job. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/elasticsearch/api/actions/connector/sync_job_error.rb', line 37

def sync_job_error(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.sync_job_error' }

  defined_params = [:connector_sync_job_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]

  unless arguments[:connector_sync_job_id]
    raise ArgumentError,
          "Required argument 'connector_sync_job_id' missing"
  end

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_sync_job_id = arguments.delete(:connector_sync_job_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/_sync_job/#{Utils.__listify(_connector_sync_job_id)}/_error"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#sync_job_get(arguments = {}) ⇒ Object

Get a connector sync job This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_sync_job_id (String)

    The unique identifier of the connector sync job to be returned.

  • :headers (Hash)

    Custom HTTP headers

See Also:



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/elasticsearch/api/actions/connector/sync_job_get.rb', line 36

def sync_job_get(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.sync_job_get' }

  defined_params = [:connector_sync_job_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  unless arguments[:connector_sync_job_id]
    raise ArgumentError,
          "Required argument 'connector_sync_job_id' missing"
  end

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _connector_sync_job_id = arguments.delete(:connector_sync_job_id)

  method = Elasticsearch::API::HTTP_GET
  path   = "_connector/_sync_job/#{Utils.__listify(_connector_sync_job_id)}"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#sync_job_list(arguments = {}) ⇒ Object

Get all connector sync jobs This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :from (Integer)

    Starting offset (default: 0)

  • :size (Integer)

    specifies a max number of results to get (default: 100)

  • :status (String)

    Sync job status, which sync jobs are fetched for

  • :connector_id (String)

    Id of the connector to fetch the sync jobs for

  • :job_type (List)

    A comma-separated list of job types

  • :headers (Hash)

    Custom HTTP headers

See Also:



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/elasticsearch/api/actions/connector/sync_job_list.rb', line 40

def sync_job_list(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.sync_job_list' }

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body   = nil

  method = Elasticsearch::API::HTTP_GET
  path   = '_connector/_sync_job'
  params = Utils.process_params(arguments)

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#sync_job_post(arguments = {}) ⇒ Object

Create a connector sync job This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    The connector sync job data. (Required)

Raises:

  • (ArgumentError)

See Also:



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/elasticsearch/api/actions/connector/sync_job_post.rb', line 36

def sync_job_post(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.sync_job_post' }

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body   = arguments.delete(:body)

  method = Elasticsearch::API::HTTP_POST
  path   = '_connector/_sync_job'
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#sync_job_update_stats(arguments = {}) ⇒ Object

Set the connector sync job stats This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_sync_job_id (String)

    The unique identifier of the connector sync job to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    The stats to update for the connector sync job. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/elasticsearch/api/actions/connector/sync_job_update_stats.rb', line 37

def sync_job_update_stats(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.sync_job_update_stats' }

  defined_params = [:connector_sync_job_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]

  unless arguments[:connector_sync_job_id]
    raise ArgumentError,
          "Required argument 'connector_sync_job_id' missing"
  end

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_sync_job_id = arguments.delete(:connector_sync_job_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/_sync_job/#{Utils.__listify(_connector_sync_job_id)}/_stats"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_active_filtering(arguments = {}) ⇒ Object

Activate the connector draft filter This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

Raises:

  • (ArgumentError)

See Also:



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/elasticsearch/api/actions/connector/update_active_filtering.rb', line 36

def update_active_filtering(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_active_filtering' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = nil

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_filtering/_activate"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_api_key_id(arguments = {}) ⇒ Object

Update the connector API key ID This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    An object containing the connector’s API key id and/or Connector Secret document id for that API key. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_api_key_id.rb', line 37

def update_api_key_id(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_api_key_id' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_api_key_id"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_configuration(arguments = {}) ⇒ Object

Update the connector configuration This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    Mapping between field names to configuration. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_configuration.rb', line 37

def update_configuration(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_configuration' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_configuration"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_error(arguments = {}) ⇒ Object

Update the connector error field This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    An object containing the connector’s error. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_error.rb', line 37

def update_error(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_error' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_error"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_features(arguments = {}) ⇒ Object

Update the connector features This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    An object containing the connector’s features definition. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_features.rb', line 37

def update_features(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_features' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_features"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_filtering(arguments = {}) ⇒ Object

Update the connector filtering This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    A list of connector filtering configurations. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_filtering.rb', line 37

def update_filtering(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_filtering' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_filtering"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_filtering_validation(arguments = {}) ⇒ Object

Update the connector draft filtering validation This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    Validation info for the draft filtering rules (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_filtering_validation.rb', line 37

def update_filtering_validation(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_filtering_validation' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_filtering/_validation"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_index_name(arguments = {}) ⇒ Object

Update the connector index name This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    An object containing the connector’s index name. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_index_name.rb', line 37

def update_index_name(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_index_name' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_index_name"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_name(arguments = {}) ⇒ Object

Update the connector name and description This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    An object containing the connector’s name and/or description. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_name.rb', line 37

def update_name(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_name' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_name"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_native(arguments = {}) ⇒ Object

Update the connector is_native flag This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    An object containing the connector’s is_native flag (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_native.rb', line 37

def update_native(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_native' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_native"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_pipeline(arguments = {}) ⇒ Object

Update the connector pipeline This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    An object with connector ingest pipeline configuration. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_pipeline.rb', line 37

def update_pipeline(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_pipeline' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_pipeline"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_scheduling(arguments = {}) ⇒ Object

Update the connector scheduling This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    An object containing the connector’s scheduling configuration. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_scheduling.rb', line 37

def update_scheduling(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_scheduling' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_scheduling"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_service_type(arguments = {}) ⇒ Object

Update the connector service type This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    An object containing the connector’s service type. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_service_type.rb', line 37

def update_service_type(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_service_type' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_service_type"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end

#update_status(arguments = {}) ⇒ Object

Update the connector status This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.

Parameters:

  • arguments (Hash) (defaults to: {})

    a customizable set of options

Options Hash (arguments):

  • :connector_id (String)

    The unique identifier of the connector to be updated.

  • :headers (Hash)

    Custom HTTP headers

  • :body (Hash)

    An object containing the connector’s status. (Required)

Raises:

  • (ArgumentError)

See Also:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/elasticsearch/api/actions/connector/update_status.rb', line 37

def update_status(arguments = {})
  request_opts = { endpoint: arguments[:endpoint] || 'connector.update_status' }

  defined_params = [:connector_id].each_with_object({}) do |variable, set_variables|
    set_variables[variable] = arguments[variable] if arguments.key?(variable)
  end
  request_opts[:defined_params] = defined_params unless defined_params.empty?

  raise ArgumentError, "Required argument 'body' missing" unless arguments[:body]
  raise ArgumentError, "Required argument 'connector_id' missing" unless arguments[:connector_id]

  arguments = arguments.clone
  headers = arguments.delete(:headers) || {}

  body = arguments.delete(:body)

  _connector_id = arguments.delete(:connector_id)

  method = Elasticsearch::API::HTTP_PUT
  path   = "_connector/#{Utils.__listify(_connector_id)}/_status"
  params = {}

  Elasticsearch::API::Response.new(
    perform_request(method, path, params, body, headers, request_opts)
  )
end