Module: Elasticsearch::API::Features::Actions
- Included in:
- FeaturesClient
- Defined in:
- lib/elasticsearch/api/namespace/features.rb,
lib/elasticsearch/api/actions/features/get_features.rb,
lib/elasticsearch/api/actions/features/reset_features.rb
Instance Method Summary collapse
-
#get_features(arguments = {}) ⇒ Object
Get the features.
-
#reset_features(arguments = {}) ⇒ Object
Reset the features This functionality is Experimental and may be changed or removed completely in a future release.
Instance Method Details
#get_features(arguments = {}) ⇒ Object
Get the features
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/elasticsearch/api/actions/features/get_features.rb', line 32 def get_features(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'features.get_features' } arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil method = Elasticsearch::API::HTTP_GET path = '_features' params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#reset_features(arguments = {}) ⇒ Object
Reset the features This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/elasticsearch/api/actions/features/reset_features.rb', line 36 def reset_features(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'features.reset_features' } arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil method = Elasticsearch::API::HTTP_POST path = '_features/_reset' params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |