Method: Elasticsearch::API::Indices::Actions#clear_cache
- Defined in:
- lib/elasticsearch/api/actions/indices/clear_cache.rb
#clear_cache(arguments = {}) ⇒ Object
Clear the cache. Clear the cache of one or more indices. For data streams, the API clears the caches of the stream’s backing indices. By default, the clear cache API clears all caches. To clear only specific caches, use the fielddata, query, or request parameters. To clear the cache only of specific fields, use the fields parameter.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/elasticsearch/api/actions/indices/clear_cache.rb', line 61 def clear_cache(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'indices.clear_cache' } defined_params = [:index].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _index = arguments.delete(:index) method = Elasticsearch::API::HTTP_POST path = if _index "#{Utils.listify(_index)}/_cache/clear" else '_cache/clear' end params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |