Module: Elasticsearch::API::Rollup::Actions
- Included in:
- RollupClient
- Defined in:
- lib/elasticsearch/api/namespace/rollup.rb,
lib/elasticsearch/api/actions/rollup/put_job.rb,
lib/elasticsearch/api/actions/rollup/get_jobs.rb,
lib/elasticsearch/api/actions/rollup/stop_job.rb,
lib/elasticsearch/api/actions/rollup/start_job.rb,
lib/elasticsearch/api/actions/rollup/delete_job.rb,
lib/elasticsearch/api/actions/rollup/rollup_search.rb,
lib/elasticsearch/api/actions/rollup/get_rollup_caps.rb,
lib/elasticsearch/api/actions/rollup/get_rollup_index_caps.rb
Instance Method Summary collapse
-
#delete_job(arguments = {}) ⇒ Object
Delete a rollup job This functionality is Experimental and may be changed or removed completely in a future release.
-
#get_jobs(arguments = {}) ⇒ Object
Get rollup job information This functionality is Experimental and may be changed or removed completely in a future release.
-
#get_rollup_caps(arguments = {}) ⇒ Object
Get the rollup job capabilities This functionality is Experimental and may be changed or removed completely in a future release.
-
#get_rollup_index_caps(arguments = {}) ⇒ Object
Get the rollup index capabilities This functionality is Experimental and may be changed or removed completely in a future release.
-
#put_job(arguments = {}) ⇒ Object
Create a rollup job This functionality is Experimental and may be changed or removed completely in a future release.
-
#rollup_search(arguments = {}) ⇒ Object
Search rolled-up data This functionality is Experimental and may be changed or removed completely in a future release.
-
#start_job(arguments = {}) ⇒ Object
Start rollup jobs This functionality is Experimental and may be changed or removed completely in a future release.
-
#stop_job(arguments = {}) ⇒ Object
Stop rollup jobs This functionality is Experimental and may be changed or removed completely in a future release.
Instance Method Details
#delete_job(arguments = {}) ⇒ Object
Delete a rollup job This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/elasticsearch/api/actions/rollup/delete_job.rb', line 36 def delete_job(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'rollup.delete_job' } defined_params = [:id].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'id' missing" unless arguments[:id] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _id = arguments.delete(:id) method = Elasticsearch::API::HTTP_DELETE path = "_rollup/job/#{Utils.__listify(_id)}" params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#get_jobs(arguments = {}) ⇒ Object
Get rollup job information This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/elasticsearch/api/actions/rollup/get_jobs.rb', line 36 def get_jobs(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'rollup.get_jobs' } defined_params = [:id].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _id = arguments.delete(:id) method = Elasticsearch::API::HTTP_GET path = if _id "_rollup/job/#{Utils.__listify(_id)}" else '_rollup/job' end params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#get_rollup_caps(arguments = {}) ⇒ Object
Get the rollup job capabilities This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/elasticsearch/api/actions/rollup/get_rollup_caps.rb', line 36 def get_rollup_caps(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'rollup.get_rollup_caps' } defined_params = [:id].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _id = arguments.delete(:id) method = Elasticsearch::API::HTTP_GET path = if _id "_rollup/data/#{Utils.__listify(_id)}" else '_rollup/data' end params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#get_rollup_index_caps(arguments = {}) ⇒ Object
Get the rollup index capabilities This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/elasticsearch/api/actions/rollup/get_rollup_index_caps.rb', line 36 def get_rollup_index_caps(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'rollup.get_rollup_index_caps' } defined_params = [:index].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'index' missing" unless arguments[:index] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _index = arguments.delete(:index) method = Elasticsearch::API::HTTP_GET path = "#{Utils.__listify(_index)}/_rollup/data" params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#put_job(arguments = {}) ⇒ Object
Create a rollup job This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/elasticsearch/api/actions/rollup/put_job.rb', line 37 def put_job(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'rollup.put_job' } defined_params = [:id].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'body' missing" unless arguments[:body] raise ArgumentError, "Required argument 'id' missing" unless arguments[:id] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = arguments.delete(:body) _id = arguments.delete(:id) method = Elasticsearch::API::HTTP_PUT path = "_rollup/job/#{Utils.__listify(_id)}" params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#rollup_search(arguments = {}) ⇒ Object
Search rolled-up data This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/elasticsearch/api/actions/rollup/rollup_search.rb', line 39 def rollup_search(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'rollup.rollup_search' } defined_params = [:index].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'body' missing" unless arguments[:body] raise ArgumentError, "Required argument 'index' missing" unless arguments[:index] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = arguments.delete(:body) _index = arguments.delete(:index) method = Elasticsearch::API::HTTP_POST path = "#{Utils.__listify(_index)}/_rollup_search" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#start_job(arguments = {}) ⇒ Object
Start rollup jobs This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/elasticsearch/api/actions/rollup/start_job.rb', line 36 def start_job(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'rollup.start_job' } defined_params = [:id].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'id' missing" unless arguments[:id] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _id = arguments.delete(:id) method = Elasticsearch::API::HTTP_POST path = "_rollup/job/#{Utils.__listify(_id)}/_start" params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#stop_job(arguments = {}) ⇒ Object
Stop rollup jobs This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/elasticsearch/api/actions/rollup/stop_job.rb', line 38 def stop_job(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'rollup.stop_job' } defined_params = [:id].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'id' missing" unless arguments[:id] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _id = arguments.delete(:id) method = Elasticsearch::API::HTTP_POST path = "_rollup/job/#{Utils.__listify(_id)}/_stop" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |