Module: Elasticsearch::API::Simulate::Actions
- Included in:
- SimulateClient
- Defined in:
- lib/elasticsearch/api/namespace/simulate.rb,
lib/elasticsearch/api/actions/simulate/ingest.rb
Instance Method Summary collapse
-
#ingest(arguments = {}) ⇒ Object
Simulate data ingestion This functionality is Experimental and may be changed or removed completely in a future release.
Instance Method Details
#ingest(arguments = {}) ⇒ Object
Simulate data ingestion This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/elasticsearch/api/actions/simulate/ingest.rb', line 38 def ingest(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'simulate.ingest' } defined_params = [:index].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'body' missing" unless arguments[:body] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = arguments.delete(:body) _index = arguments.delete(:index) method = Elasticsearch::API::HTTP_POST path = if _index "_ingest/#{Utils.__listify(_index)}/_simulate" else '_ingest/_simulate' end params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |