Method: Elasticsearch::API::Cat::Actions#allocation
- Defined in:
- lib/elasticsearch/api/actions/cat/allocation.rb
#allocation(arguments = {}) ⇒ Object
Provides a snapshot of how many shards are allocated to each data node and how much disk space they are using.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/elasticsearch/api/actions/cat/allocation.rb', line 40 def allocation(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || "cat.allocation" } defined_params = [:node_id].inject({}) do |set_variables, variable| set_variables[variable] = arguments[variable] if arguments.key?(variable) set_variables end request_opts[:defined_params] = defined_params unless defined_params.empty? arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _node_id = arguments.delete(:node_id) method = Elasticsearch::API::HTTP_GET path = if _node_id "_cat/allocation/#{Utils.__listify(_node_id)}" else "_cat/allocation" end params = Utils.process_params(arguments) params[:h] = Utils.__listify(params[:h]) if params[:h] Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |