Method: Elasticsearch::API::Cluster::Actions#reroute
- Defined in:
- lib/elasticsearch/api/actions/cluster/reroute.rb
#reroute(arguments = {}) ⇒ Object
Note:
If you want to explicitely set the shard allocation to a certain node, you might want to look at the allocation.* cluster settings.
Perform manual shard allocation in the cluster.
Pass the operations you want to perform in the :body option. Use the dry_run option to evaluate the result of operations without actually performing them.
28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/elasticsearch/api/actions/cluster/reroute.rb', line 28 def reroute(arguments={}) valid_params = [ :dry_run, :filter_metadata ] method = 'POST' path = "_cluster/reroute" params = Utils.__validate_and_extract_params arguments, valid_params body = arguments[:body] || {} perform_request(method, path, params, body).body end |