Method: Elasticsearch::API::Tasks::Actions#get
- Defined in:
- lib/elasticsearch/api/actions/tasks/get.rb
#get(arguments = {}) ⇒ Object
Returns information about a task. This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/elasticsearch/api/actions/tasks/get.rb', line 38 def get(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'tasks.get' } defined_params = [:task_id].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _task_id = arguments.delete(:task_id) method = Elasticsearch::API::HTTP_GET path = "_tasks/#{Utils.__listify(_task_id)}" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |