Module: Elasticsearch::API::Project::Actions
- Defined in:
- lib/elasticsearch/api/actions/project/tags.rb,
lib/elasticsearch/api/actions/project/get_routing.rb,
lib/elasticsearch/api/actions/project/create_routing.rb,
lib/elasticsearch/api/actions/project/delete_routing.rb,
lib/elasticsearch/api/actions/project/get_many_routing.rb,
lib/elasticsearch/api/actions/project/create_many_routing.rb
Instance Method Summary collapse
-
#create_many_routing(arguments = {}) ⇒ Object
Create or update project routing expressions.
-
#create_routing(arguments = {}) ⇒ Object
Create or update a project routing expression.
-
#delete_routing(arguments = {}) ⇒ Object
Delete a project routing expression.
-
#get_many_routing(arguments = {}) ⇒ Object
Get project routing expressions.
-
#get_routing(arguments = {}) ⇒ Object
Get a project routing expression.
-
#tags(arguments = {}) ⇒ Object
Get tags.
Instance Method Details
#create_many_routing(arguments = {}) ⇒ Object
Create or update project routing expressions.
This API is only available in Serverless.
This functionality is in technical preview and may be changed or removed in a future release. Elastic will apply best effort to fix any issues, but features in technical preview are not subject to the support SLA of official GA features.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/elasticsearch/api/actions/project/create_many_routing.rb', line 47 def create_many_routing(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'project.create_many_routing' } raise ArgumentError, "Required argument 'body' missing" unless arguments[:body] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = arguments.delete(:body) method = Elasticsearch::API::HTTP_PUT path = '_project_routing' params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#create_routing(arguments = {}) ⇒ Object
Create or update a project routing expression.
This API is only available in Serverless.
This functionality is in technical preview and may be changed or removed in a future release. Elastic will apply best effort to fix any issues, but features in technical preview are not subject to the support SLA of official GA features.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/elasticsearch/api/actions/project/create_routing.rb', line 48 def create_routing(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'project.create_routing' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'body' missing" unless arguments[:body] raise ArgumentError, "Required argument 'name' missing" unless arguments[:name] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = arguments.delete(:body) _name = arguments.delete(:name) method = Elasticsearch::API::HTTP_PUT path = "_project_routing/#{Utils.listify(_name)}" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#delete_routing(arguments = {}) ⇒ Object
Delete a project routing expression.
This API is only available in Serverless.
This functionality is in technical preview and may be changed or removed in a future release. Elastic will apply best effort to fix any issues, but features in technical preview are not subject to the support SLA of official GA features.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/elasticsearch/api/actions/project/delete_routing.rb', line 47 def delete_routing(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'project.delete_routing' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'name' missing" unless arguments[:name] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _name = arguments.delete(:name) method = Elasticsearch::API::HTTP_DELETE path = "_project_routing/#{Utils.listify(_name)}" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#get_many_routing(arguments = {}) ⇒ Object
Get project routing expressions.
This API is only available in Serverless.
This functionality is in technical preview and may be changed or removed in a future release. Elastic will apply best effort to fix any issues, but features in technical preview are not subject to the support SLA of official GA features.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/elasticsearch/api/actions/project/get_many_routing.rb', line 46 def get_many_routing(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'project.get_many_routing' } arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil method = Elasticsearch::API::HTTP_GET path = '_project_routing' params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#get_routing(arguments = {}) ⇒ Object
Get a project routing expression.
This API is only available in Serverless.
This functionality is in technical preview and may be changed or removed in a future release. Elastic will apply best effort to fix any issues, but features in technical preview are not subject to the support SLA of official GA features.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/elasticsearch/api/actions/project/get_routing.rb', line 47 def get_routing(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'project.get_routing' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'name' missing" unless arguments[:name] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _name = arguments.delete(:name) method = Elasticsearch::API::HTTP_GET path = "_project_routing/#{Utils.listify(_name)}" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#tags(arguments = {}) ⇒ Object
Get tags. Get the tags that are defined for the project.
This API is only available in Serverless.
This functionality is in technical preview and may be changed or removed in a future release. Elastic will apply best effort to fix any issues, but features in technical preview are not subject to the support SLA of official GA features.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/elasticsearch/api/actions/project/tags.rb', line 50 def (arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'project.tags' } arguments = arguments.clone headers = arguments.delete(:headers) || {} body = arguments.delete(:body) method = if body Elasticsearch::API::HTTP_POST else Elasticsearch::API::HTTP_GET end path = '_project/tags' params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |