Module: Elasticsearch::API::SearchApplication::Actions
- Included in:
- SearchApplicationClient
- Defined in:
- lib/elasticsearch/api/namespace/search_application.rb,
lib/elasticsearch/api/actions/search_application/get.rb,
lib/elasticsearch/api/actions/search_application/put.rb,
lib/elasticsearch/api/actions/search_application/list.rb,
lib/elasticsearch/api/actions/search_application/delete.rb,
lib/elasticsearch/api/actions/search_application/search.rb,
lib/elasticsearch/api/actions/search_application/render_query.rb,
lib/elasticsearch/api/actions/search_application/get_behavioral_analytics.rb,
lib/elasticsearch/api/actions/search_application/put_behavioral_analytics.rb,
lib/elasticsearch/api/actions/search_application/delete_behavioral_analytics.rb,
lib/elasticsearch/api/actions/search_application/post_behavioral_analytics_event.rb
Instance Method Summary collapse
-
#delete(arguments = {}) ⇒ Object
Delete a search application This functionality is in Beta and is subject to change.
-
#delete_behavioral_analytics(arguments = {}) ⇒ Object
Delete a behavioral analytics collection This functionality is Experimental and may be changed or removed completely in a future release.
-
#get(arguments = {}) ⇒ Object
Get search application details This functionality is in Beta and is subject to change.
-
#get_behavioral_analytics(arguments = {}) ⇒ Object
Get behavioral analytics collections This functionality is Experimental and may be changed or removed completely in a future release.
-
#list(arguments = {}) ⇒ Object
Get search applications This functionality is in Beta and is subject to change.
-
#post_behavioral_analytics_event(arguments = {}) ⇒ Object
Create a behavioral analytics collection event This functionality is Experimental and may be changed or removed completely in a future release.
-
#put(arguments = {}) ⇒ Object
Create or update a search application This functionality is in Beta and is subject to change.
-
#put_behavioral_analytics(arguments = {}) ⇒ Object
Create a behavioral analytics collection This functionality is Experimental and may be changed or removed completely in a future release.
-
#render_query(arguments = {}) ⇒ Object
Render a search application query This functionality is Experimental and may be changed or removed completely in a future release.
-
#search(arguments = {}) ⇒ Object
Run a search application search This functionality is in Beta and is subject to change.
Instance Method Details
#delete(arguments = {}) ⇒ Object
Delete a search application This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/elasticsearch/api/actions/search_application/delete.rb', line 36 def delete(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'search_application.delete' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'name' missing" unless arguments[:name] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _name = arguments.delete(:name) method = Elasticsearch::API::HTTP_DELETE path = "_application/search_application/#{Utils.__listify(_name)}" params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#delete_behavioral_analytics(arguments = {}) ⇒ Object
Delete a behavioral analytics collection This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/elasticsearch/api/actions/search_application/delete_behavioral_analytics.rb', line 36 def delete_behavioral_analytics(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'search_application.delete_behavioral_analytics' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'name' missing" unless arguments[:name] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _name = arguments.delete(:name) method = Elasticsearch::API::HTTP_DELETE path = "_application/analytics/#{Utils.__listify(_name)}" params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#get(arguments = {}) ⇒ Object
Get search application details This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/elasticsearch/api/actions/search_application/get.rb', line 36 def get(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'search_application.get' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'name' missing" unless arguments[:name] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _name = arguments.delete(:name) method = Elasticsearch::API::HTTP_GET path = "_application/search_application/#{Utils.__listify(_name)}" params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#get_behavioral_analytics(arguments = {}) ⇒ Object
Get behavioral analytics collections This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/elasticsearch/api/actions/search_application/get_behavioral_analytics.rb', line 36 def get_behavioral_analytics(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'search_application.get_behavioral_analytics' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _name = arguments.delete(:name) method = Elasticsearch::API::HTTP_GET path = if _name "_application/analytics/#{Utils.__listify(_name)}" else '_application/analytics' end params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#list(arguments = {}) ⇒ Object
Get search applications This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/elasticsearch/api/actions/search_application/list.rb', line 38 def list(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'search_application.list' } arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil method = Elasticsearch::API::HTTP_GET path = '_application/search_application' params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#post_behavioral_analytics_event(arguments = {}) ⇒ Object
Create a behavioral analytics collection event This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/elasticsearch/api/actions/search_application/post_behavioral_analytics_event.rb', line 39 def post_behavioral_analytics_event(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'search_application.post_behavioral_analytics_event' } defined_params = %i[collection_name event_type].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'body' missing" unless arguments[:body] raise ArgumentError, "Required argument 'collection_name' missing" unless arguments[:collection_name] raise ArgumentError, "Required argument 'event_type' missing" unless arguments[:event_type] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = arguments.delete(:body) _collection_name = arguments.delete(:collection_name) _event_type = arguments.delete(:event_type) method = Elasticsearch::API::HTTP_POST path = "_application/analytics/#{Utils.__listify(_collection_name)}/event/#{Utils.__listify(_event_type)}" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#put(arguments = {}) ⇒ Object
Create or update a search application This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/elasticsearch/api/actions/search_application/put.rb', line 38 def put(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'search_application.put' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'body' missing" unless arguments[:body] raise ArgumentError, "Required argument 'name' missing" unless arguments[:name] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = arguments.delete(:body) _name = arguments.delete(:name) method = Elasticsearch::API::HTTP_PUT path = "_application/search_application/#{Utils.__listify(_name)}" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#put_behavioral_analytics(arguments = {}) ⇒ Object
Create a behavioral analytics collection This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/elasticsearch/api/actions/search_application/put_behavioral_analytics.rb', line 36 def put_behavioral_analytics(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'search_application.put_behavioral_analytics' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'name' missing" unless arguments[:name] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _name = arguments.delete(:name) method = Elasticsearch::API::HTTP_PUT path = "_application/analytics/#{Utils.__listify(_name)}" params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#render_query(arguments = {}) ⇒ Object
Render a search application query This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/elasticsearch/api/actions/search_application/render_query.rb', line 37 def render_query(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'search_application.render_query' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'name' missing" unless arguments[:name] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = arguments.delete(:body) _name = arguments.delete(:name) method = Elasticsearch::API::HTTP_POST path = "_application/search_application/#{Utils.__listify(_name)}/_render_query" params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#search(arguments = {}) ⇒ Object
Run a search application search This functionality is in Beta and is subject to change. The design and code is less mature than official GA features and is being provided as-is with no warranties. Beta features are not subject to the support SLA of official GA features.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/elasticsearch/api/actions/search_application/search.rb', line 38 def search(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'search_application.search' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'name' missing" unless arguments[:name] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = arguments.delete(:body) _name = arguments.delete(:name) method = if body Elasticsearch::API::HTTP_POST else Elasticsearch::API::HTTP_GET end path = "_application/search_application/#{Utils.__listify(_name)}/_search" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |