Module: Elasticsearch::API::SearchableSnapshots::Actions
- Included in:
- SearchableSnapshotsClient
- Defined in:
- lib/elasticsearch/api/namespace/searchable_snapshots.rb,
lib/elasticsearch/api/actions/searchable_snapshots/mount.rb,
lib/elasticsearch/api/actions/searchable_snapshots/stats.rb,
lib/elasticsearch/api/actions/searchable_snapshots/cache_stats.rb,
lib/elasticsearch/api/actions/searchable_snapshots/clear_cache.rb
Instance Method Summary collapse
-
#cache_stats(arguments = {}) ⇒ Object
Get cache statistics This functionality is Experimental and may be changed or removed completely in a future release.
-
#clear_cache(arguments = {}) ⇒ Object
Clear the cache of searchable snapshots.
-
#mount(arguments = {}) ⇒ Object
Mount a snapshot.
-
#stats(arguments = {}) ⇒ Object
Get searchable snapshot statistics.
Instance Method Details
#cache_stats(arguments = {}) ⇒ Object
Get cache statistics This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/elasticsearch/api/actions/searchable_snapshots/cache_stats.rb', line 36 def cache_stats(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'searchable_snapshots.cache_stats' } defined_params = [:node_id].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _node_id = arguments.delete(:node_id) method = Elasticsearch::API::HTTP_GET path = if _node_id "_searchable_snapshots/#{Utils.__listify(_node_id)}/cache/stats" else '_searchable_snapshots/cache/stats' end params = {} Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#clear_cache(arguments = {}) ⇒ Object
Clear the cache of searchable snapshots. This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/elasticsearch/api/actions/searchable_snapshots/clear_cache.rb', line 39 def clear_cache(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'searchable_snapshots.clear_cache' } defined_params = [:index].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _index = arguments.delete(:index) method = Elasticsearch::API::HTTP_POST path = if _index "#{Utils.__listify(_index)}/_searchable_snapshots/cache/clear" else '_searchable_snapshots/cache/clear' end params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#mount(arguments = {}) ⇒ Object
Mount a snapshot
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/elasticsearch/api/actions/searchable_snapshots/mount.rb', line 37 def mount(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'searchable_snapshots.mount' } defined_params = %i[repository snapshot].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'body' missing" unless arguments[:body] raise ArgumentError, "Required argument 'repository' missing" unless arguments[:repository] raise ArgumentError, "Required argument 'snapshot' missing" unless arguments[:snapshot] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = arguments.delete(:body) _repository = arguments.delete(:repository) _snapshot = arguments.delete(:snapshot) method = Elasticsearch::API::HTTP_POST path = "_snapshot/#{Utils.__listify(_repository)}/#{Utils.__listify(_snapshot)}/_mount" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#stats(arguments = {}) ⇒ Object
Get searchable snapshot statistics
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/elasticsearch/api/actions/searchable_snapshots/stats.rb', line 33 def stats(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'searchable_snapshots.stats' } defined_params = [:index].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _index = arguments.delete(:index) method = Elasticsearch::API::HTTP_GET path = if _index "#{Utils.__listify(_index)}/_searchable_snapshots/stats" else '_searchable_snapshots/stats' end params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |