Module: Elasticsearch::API::Streams::Actions
- Defined in:
- lib/elasticsearch/api/actions/streams/status.rb,
lib/elasticsearch/api/actions/streams/logs_enable.rb,
lib/elasticsearch/api/actions/streams/logs_disable.rb
Instance Method Summary collapse
-
#logs_disable(arguments = {}) ⇒ Object
Disable a named stream.
-
#logs_enable(arguments = {}) ⇒ Object
Enable a named stream.
-
#status(arguments = {}) ⇒ Object
Get the status of streams.
Instance Method Details
#logs_disable(arguments = {}) ⇒ Object
Disable a named stream. Turn off the named stream feature for this cluster. This functionality is in technical preview and may be changed or removed in a future release. Elastic will apply best effort to fix any issues, but features in technical preview are not subject to the support SLA of official GA features.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/elasticsearch/api/actions/streams/logs_disable.rb', line 51 def logs_disable(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'streams.logs_disable' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'name' missing" unless arguments[:name] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _name = arguments.delete(:name) method = Elasticsearch::API::HTTP_POST path = "_streams/#{Utils.listify(_name)}/_disable" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#logs_enable(arguments = {}) ⇒ Object
Enable a named stream. Turn on the named stream feature for this cluster. NOTE: To protect existing data, this feature can be turned on only if the cluster does not have existing indices or data streams that match the pattern ‘<name>|<name>.*` for the enabled stream type name. If those indices or data streams exist, a `409 - Conflict` response and error is returned. This functionality is in technical preview and may be changed or removed in a future release. Elastic will apply best effort to fix any issues, but features in technical preview are not subject to the support SLA of official GA features.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/elasticsearch/api/actions/streams/logs_enable.rb', line 55 def logs_enable(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'streams.logs_enable' } defined_params = [:name].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'name' missing" unless arguments[:name] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _name = arguments.delete(:name) method = Elasticsearch::API::HTTP_POST path = "_streams/#{Utils.listify(_name)}/_enable" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#status(arguments = {}) ⇒ Object
Get the status of streams. Get the current status for all types of streams. This functionality is in technical preview and may be changed or removed in a future release. Elastic will apply best effort to fix any issues, but features in technical preview are not subject to the support SLA of official GA features.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/elasticsearch/api/actions/streams/status.rb', line 47 def status(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'streams.status' } arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil method = Elasticsearch::API::HTTP_GET path = '_streams/status' params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |