Module: Elasticsearch::API::Tasks::Actions
- Defined in:
- lib/elasticsearch/api/actions/tasks/get.rb,
lib/elasticsearch/api/actions/tasks/list.rb,
lib/elasticsearch/api/actions/tasks/cancel.rb
Instance Method Summary collapse
-
#cancel(arguments = {}) ⇒ Object
Cancel a task.
-
#get(arguments = {}) ⇒ Object
Get task information.
-
#list(arguments = {}) ⇒ Object
Get all tasks.
Instance Method Details
#cancel(arguments = {}) ⇒ Object
Cancel a task.
WARNING: The task management API is new and should still be considered a beta feature.
The API may change in ways that are not backwards compatible.
A task may continue to run for some time after it has been cancelled because it may not be able to safely stop its current activity straight away.
It is also possible that Elasticsearch must complete its work on other tasks before it can process the cancellation.
The get task information API will continue to list these cancelled tasks until they complete.
The cancelled flag in the response indicates that the cancellation command has been processed and the task will stop as soon as possible.
To troubleshoot why a cancelled task does not complete promptly, use the get task information API with the ?detailed parameter to identify the other tasks the system is running.
You can also use the node hot threads API to obtain detailed information about the work the system is doing instead of completing the cancelled task.
For relocatable tasks, this API transparently follows the task across graceful shutdown relocations,
so callers can keep using the original task ID. The returned task reports its original_task_id and original_start_time_in_millis
if it is continuing work from an earlier task.
This functionality is experimental and is not ready for production usage. Experimental
features may change or be removed at any time. Elastic will work to fix any issues, but
experimental features are not subject to the support SLA of official GA features. Specific
Support terms apply.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/elasticsearch/api/actions/tasks/cancel.rb', line 62 def cancel(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'tasks.cancel' } defined_params = [:task_id].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _task_id = arguments.delete(:task_id) method = Elasticsearch::API::HTTP_POST path = if _task_id "_tasks/#{Utils.listify(_task_id)}/_cancel" else '_tasks/_cancel' end params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#get(arguments = {}) ⇒ Object
Get task information.
Get information about a task currently running in the cluster.
WARNING: The task management API is new and should still be considered a beta feature.
The API may change in ways that are not backwards compatible.
If the task identifier is not found, a 404 response code indicates that there are no resources that match the request.
For relocatable tasks, this API transparently follows the task across graceful shutdown relocations,
so callers can keep using the original task ID. The returned task reports its original_task_id and original_start_time_in_millis
if it is continuing work from an earlier task.
This functionality is experimental and is not ready for production usage. Experimental
features may change or be removed at any time. Elastic will work to fix any issues, but
experimental features are not subject to the support SLA of official GA features. Specific
Support terms apply.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/elasticsearch/api/actions/tasks/get.rb', line 58 def get(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'tasks.get' } defined_params = [:task_id].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? raise ArgumentError, "Required argument 'task_id' missing" unless arguments[:task_id] arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _task_id = arguments.delete(:task_id) method = Elasticsearch::API::HTTP_GET path = "_tasks/#{Utils.listify(_task_id)}" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#list(arguments = {}) ⇒ Object
Get all tasks.
Get information about the tasks currently running on one or more nodes in the cluster.
WARNING: The task management API is new and should still be considered a beta feature.
The API may change in ways that are not backwards compatible.
For relocatable tasks, this API transparently follows the task across graceful shutdown relocations,
so callers can keep using the original task ID. The returned task reports its original_task_id and original_start_time_in_millis
if it is continuing work from an earlier task.
Identifying running tasks
The X-Opaque-Id header, when provided on the HTTP request header, is going to be returned as a header in the response as well as in the headers field for in the task information.
This enables you to track certain calls or associate certain tasks with the client that started them.
For example:
curl -i -H "X-Opaque-Id: 123456" "http://localhost:9200/_tasks?group_by=parents"
The API returns the following result:
HTTP/1.1 200 OK
X-Opaque-Id: 123456
content-type: application/json; charset=UTF-8
content-length: 831
{
"tasks" : {
"u5lcZHqcQhu-rUoFaqDphA:45" : {
"node" : "u5lcZHqcQhu-rUoFaqDphA",
"id" : 45,
"type" : "transport",
"action" : "cluster:monitor/tasks/lists",
"start_time_in_millis" : 1513823752749,
"running_time_in_nanos" : 293139,
"cancellable" : false,
"headers" : {
"X-Opaque-Id" : "123456"
},
"children" : [
{
"node" : "u5lcZHqcQhu-rUoFaqDphA",
"id" : 46,
"type" : "direct",
"action" : "cluster:monitor/tasks/lists[n]",
"start_time_in_millis" : 1513823752750,
"running_time_in_nanos" : 92133,
"cancellable" : false,
"parent_task_id" : "u5lcZHqcQhu-rUoFaqDphA:45",
"headers" : {
"X-Opaque-Id" : "123456"
}
}
]
}
}
}
In this example, X-Opaque-Id: 123456 is the ID as a part of the response header.
The X-Opaque-Id in the task headers is the ID for the task that was initiated by the REST request.
The X-Opaque-Id in the children headers is the child task of the task that was initiated by the REST request.
This functionality is experimental and is not ready for production usage. Experimental
features may change or be removed at any time. Elastic will work to fix any issues, but
experimental features are not subject to the support SLA of official GA features. Specific
Support terms apply.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/elasticsearch/api/actions/tasks/list.rb', line 118 def list(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'tasks.list' } arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil method = Elasticsearch::API::HTTP_GET path = '_tasks' params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |