Module: Elasticsearch::API::Tasks::Actions
- Included in:
- TasksClient
- Defined in:
- lib/elasticsearch/api/namespace/tasks.rb,
lib/elasticsearch/api/actions/tasks/get.rb,
lib/elasticsearch/api/actions/tasks/list.rb,
lib/elasticsearch/api/actions/tasks/cancel.rb
Instance Method Summary collapse
-
#cancel(arguments = {}) ⇒ Object
Cancel a task This functionality is Experimental and may be changed or removed completely in a future release.
-
#get(arguments = {}) ⇒ Object
Get task information This functionality is Experimental and may be changed or removed completely in a future release.
-
#list(arguments = {}) ⇒ Object
Get all tasks This functionality is Experimental and may be changed or removed completely in a future release.
Instance Method Details
#cancel(arguments = {}) ⇒ Object
Cancel a task This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/elasticsearch/api/actions/tasks/cancel.rb', line 40 def cancel(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'tasks.cancel' } defined_params = [:task_id].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _task_id = arguments.delete(:task_id) method = Elasticsearch::API::HTTP_POST path = if _task_id "_tasks/#{Utils.__listify(_task_id)}/_cancel" else '_tasks/_cancel' end params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#get(arguments = {}) ⇒ Object
Get task information This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/elasticsearch/api/actions/tasks/get.rb', line 38 def get(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'tasks.get' } defined_params = [:task_id].each_with_object({}) do |variable, set_variables| set_variables[variable] = arguments[variable] if arguments.key?(variable) end request_opts[:defined_params] = defined_params unless defined_params.empty? arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil _task_id = arguments.delete(:task_id) method = Elasticsearch::API::HTTP_GET path = "_tasks/#{Utils.__listify(_task_id)}" params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |
#list(arguments = {}) ⇒ Object
Get all tasks This functionality is Experimental and may be changed or removed completely in a future release. Elastic will take a best effort approach to fix any issues, but experimental features are not subject to the support SLA of official GA features.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/elasticsearch/api/actions/tasks/list.rb', line 42 def list(arguments = {}) request_opts = { endpoint: arguments[:endpoint] || 'tasks.list' } arguments = arguments.clone headers = arguments.delete(:headers) || {} body = nil method = Elasticsearch::API::HTTP_GET path = '_tasks' params = Utils.process_params(arguments) Elasticsearch::API::Response.new( perform_request(method, path, params, body, headers, request_opts) ) end |